@@ -1,4 +1,9 @@
 # vim: set fileencoding=utf-8 sw=4 ts=4 et :
+
+# Parts of Cython are unusable if setuptools just built it.
+import sys
+del sys.modules['Cython']
+
 import Cython.Distutils.build_ext
 
 def ext_modules_hack(dist, attr, value):
